/**
 * OWASP AppSensor
 * 
 * This file is part of the Open Web Application Security Project (OWASP)
 * AppSensor project. For details, please see
 * <a href="http://www.owasp.org/index.php/Category:OWASP_AppSensor_Project">
 * 	http://www.owasp.org/index.php/Category:OWASP_AppSensor_Project</a>.
 *
 * Copyright (c) 2010 - The OWASP Foundation
 * 
 * AppSensor is published by OWASP under the BSD license. You should read and accept the
 * LICENSE before you use, modify, and/or redistribute this software.
 * 
 * @author Michael Coates <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @author John Melton <a href="http://www.jtmelton.com/">jtmelton</a>
 * @created 2010
 */
package org.owasp.appsensor;

import java.util.Calendar;
import java.util.Date;
import java.util.TimeZone;

/**
 * This class is simply a helper class with various date 
 * manipulation methods.
 * 
 * @author Michael Coates (michael.coates .at. owasp.org) 
 *         <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @author John Melton (jtmelton .at. gmail.com)
 *         <a href="http://www.jtmelton.com/">jtmelton</a>
 * @since February 24, 2010
 */
public class DateUtils {
	
	/**
	 * Retrieves the current time in a long format
	 * @return the current time in a long format
	 */
	public static long getCurrentTime() {
		TimeZone tz = TimeZone.getDefault();
		Calendar cal = Calendar.getInstance(tz);
		Date date = cal.getTime();
		long currentTime = date.getTime();
		return currentTime;
	}
	
	/**
	 * Retrieves the time (as of the specified number of seconds ago) as a long.  
	 * First the current time is retrieved, 
	 * then the number of seconds passed in are subtracted from the current time.
	 * Finally the time is returned.
	 * @param numberOfSecondsAgoLong number of seconds to subtract from current time
	 * @return the time (as of the specified number of seconds ago) as a long.  
	 */
	public static long getTimeNumberOfSecondsAgo(long numberOfSecondsAgoLong) {
		TimeZone tz = TimeZone.getDefault();
		Calendar cal = Calendar.getInstance(tz);
		//take away number of seconds
		int numberOfSecondsAgo = Integer.parseInt(String.valueOf(numberOfSecondsAgoLong));
		cal.add(Calendar.SECOND, -(numberOfSecondsAgo));
		Date date = cal.getTime();
		long currentTime = date.getTime();
		return currentTime;
	}
	
	/**
	 * Retrieves the time (as of the specified number of seconds ago) as a long.  
	 * First the current time is retrieved, 
	 * then the number of seconds passed in are added to the current time.
	 * Finally the time is returned.
	 * @param numberOfSecondsFromNowLong number of seconds to add to current time
	 * @return the time (as of the specified number of seconds from now) as a long.  
	 */
	public static long getTimeNumberOfSecondsFromNow(long numberOfSecondsFromNowLong) {
		TimeZone tz = TimeZone.getDefault();
		Calendar cal = Calendar.getInstance(tz);
		//take away number of seconds
		int numberOfSecondsAgo = Integer.parseInt(String.valueOf(numberOfSecondsFromNowLong));
		cal.add(Calendar.SECOND, numberOfSecondsAgo);
		Date date = cal.getTime();
		long currentTime = date.getTime();
		return currentTime;
	}
	
	/**
	 * Retrieves the current date in a java.util.Date format
	 * @return the current date in a java.util.Date format
	 */
	public static Date getCurrentDate() {
		TimeZone tz = TimeZone.getDefault();
		Calendar cal = Calendar.getInstance(tz);
		Date date = cal.getTime();
		return date;
	}
	
	/**
	 * Retrieves the current calendar in a java.util.Calendar format
	 * @return the current calendar in a java.util.Calendar format
	 */
	public static Calendar getCurrentCalendar() {
		TimeZone tz = TimeZone.getDefault();
		Calendar cal = Calendar.getInstance(tz);
		return cal;
	}
}
