/**
 * OWASP AppSensor
 * 
 * This file is part of the Open Web Application Security Project (OWASP)
 * AppSensor project. For details, please see
 * <a href="http://www.owasp.org/index.php/Category:OWASP_AppSensor_Project">
 * 	http://www.owasp.org/index.php/Category:OWASP_AppSensor_Project</a>.
 *
 * Copyright (c) 2010 - The OWASP Foundation
 * 
 * AppSensor is published by OWASP under the BSD license. You should read and accept the
 * LICENSE before you use, modify, and/or redistribute this software.
 * 
 * @author Michael Coates <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @author John Melton <a href="http://www.jtmelton.com/">jtmelton</a>
 * @created 2010
 */
package org.owasp.appsensor.reference;

import javax.servlet.http.HttpServletRequest;

import org.owasp.appsensor.ASLogger;
import org.owasp.appsensor.ASUser;
import org.owasp.appsensor.ASUtilities;
import org.owasp.appsensor.reference.adapters.ESAPIASCurrentUser;
import org.owasp.appsensor.reference.adapters.ESAPIASLogger;
import org.owasp.esapi.ESAPI;

/**
 * This class is the default implementation of the utilities helper
 * class for AppSensor.  This interface is responsible for providing 
 * the implemementation classes for a number of utility type objects 
 * that are needed throughout AppSensor.
 * <p />  
 * Since AppSensor is based on and closely tied to ESAPI, the default
 * implementation simply uses direct ESAPI classes / methods or 
 * adapters that use ESAPI implementations under the covers.  
 * 
 * @author Michael Coates (michael.coates .at. owasp.org) 
 *         <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @author John Melton (jtmelton .at. gmail.com)
 *         <a href="http://www.jtmelton.com/">jtmelton</a>
 * @since May 6, 2010
 */
public class DefaultASUtilities implements ASUtilities {
	
	private static volatile ASUtilities singletonInstance;

    public static ASUtilities getInstance()
    {
        if ( singletonInstance == null ) {
            synchronized ( DefaultASUtilities.class ) {
                if ( singletonInstance == null ) {
                    singletonInstance = new DefaultASUtilities();
                }
            }
        }
        return singletonInstance;
    }

	/**
	 * This method uses the ESAPI current user implementation
	 * @return ESAPIASCurrentUser adapter class that uses ESAPI's 
	 * 		current user implementation
	 */
	public ASUser getCurrentUser() {
		return new ESAPIASCurrentUser();
	}

	/**
	 * This method uses the ESAPI logger implementation
	 * @return ESAPIASLogger adapter class that uses ESAPI's 
	 * 		logger implementation
	 */
	public ASLogger getLogger(String className) {
		return new ESAPIASLogger(className);
	}
	
	/**
	 * This method uses the ESAPI current request implementation
	 * @return current http request retrieved from ESAPI
	 */
	public HttpServletRequest getCurrentRequest() {
		return ESAPI.httpUtilities().getCurrentRequest();
	}

}
