/**
 * OWASP AppSensor
 * 
 * This file is part of the Open Web Application Security Project (OWASP)
 * AppSensor project. For details, please see
 * <a href="http://www.owasp.org/index.php/Category:OWASP_AppSensor_Project">
 * 	http://www.owasp.org/index.php/Category:OWASP_AppSensor_Project</a>.
 *
 * Copyright (c) 2010 - The OWASP Foundation
 * 
 * AppSensor is published by OWASP under the BSD license. You should read and accept the
 * LICENSE before you use, modify, and/or redistribute this software.
 * 
 * @author Michael Coates <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @author John Melton <a href="http://www.jtmelton.com/">jtmelton</a>
 * @created 2010
 */
package org.owasp.appsensor.reference.adapters;

import org.owasp.appsensor.ASUser;
import org.owasp.esapi.ESAPI;
import org.owasp.esapi.User;

/**
 * This is a simple adapter class.  All it does is implement the ASUser interface
 * and call through to get the current user from ESAPI in order to pass through
 * the method requests.
 * 
 * @author Michael Coates (michael.coates .at. owasp.org) 
 *         <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @author John Melton (jtmelton .at. gmail.com)
 *         <a href="http://www.jtmelton.com/">jtmelton</a>
 * @since May 6, 2010
 */
public class ESAPIASCurrentUser implements ASUser {

	/**
	 * {@inheritDoc}
	 */
	public long getAccountId() {
		User u = ESAPI.authenticator().getCurrentUser();
		long acctId = u.getAccountId();
		return acctId;
	}
	
	/**
	 * {@inheritDoc}
	 */
	public String getAccountName() {
		User u = ESAPI.authenticator().getCurrentUser();
		String accountName = u.getAccountName();
		return accountName;
	}

	/**
	 * {@inheritDoc}
	 */
	public boolean isAnonymous() {
		User u = ESAPI.authenticator().getCurrentUser();
		boolean isAnonymous = u.isAnonymous();
		return isAnonymous;
	}

	/**
	 * {@inheritDoc}
	 */
	public void disable() {
		User u = ESAPI.authenticator().getCurrentUser();
		u.disable();
	}

	/**
	 * {@inheritDoc}
	 */
	public void logout() {
		User u = ESAPI.authenticator().getCurrentUser();
		u.logout();
	}

	/**
	 * {@inheritDoc}
	 */
	public boolean isEnabled() {
		User u = ESAPI.authenticator().getCurrentUser();
		boolean isEnabled = u.isEnabled();
		return isEnabled;
	}

}
