/**
 * OWASP AppSensor
 * 
 * This file is part of the Open Web Application Security Project (OWASP)
 * AppSensor project. For details, please see
 * <a href="http://www.owasp.org/index.php/Category:OWASP_AppSensor_Project">
 * 	http://www.owasp.org/index.php/Category:OWASP_AppSensor_Project</a>.
 *
 * Copyright (c) 2010 - The OWASP Foundation
 * 
 * AppSensor is published by OWASP under the BSD license. You should read and accept the
 * LICENSE before you use, modify, and/or redistribute this software.
 * 
 * @author Michael Coates <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @author John Melton <a href="http://www.jtmelton.com/">jtmelton</a>
 * @created 2010
 */
package org.owasp.appsensor.reference.adapters;

import org.owasp.appsensor.ASLogger;
import org.owasp.esapi.ESAPI;
import org.owasp.esapi.Logger;

/**
 * This is a simple adapter class.  All it does is implement the ASLogger interface
 * and call through to get the logger from ESAPI in order to pass through
 * the method requests.
 * 
 * @author Michael Coates (michael.coates .at. owasp.org) 
 *         <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @author John Melton (jtmelton .at. gmail.com)
 *         <a href="http://www.jtmelton.com/">jtmelton</a>
 * @since May 6, 2010
 */
public class ESAPIASLogger implements ASLogger {

	/**
	 * Serial Version UID for serialization
	 */
	private static final long serialVersionUID = -2439788071519581531L;
	
	private Logger esapiLogger;
	
	/**
	 * Constructor that initializes logger
	 * @param className The module to associate the logger with.
	 */
	public ESAPIASLogger(String className) {
		esapiLogger = ESAPI.getLogger(className);
	}
	
	/**
	 * {@inheritDoc}
	 */
	public void debug(String message) {
		esapiLogger.debug(Logger.SECURITY_FAILURE, message);
	}

	/**
	 * {@inheritDoc}
	 */
	public void debug(String message, Throwable throwable) {
		esapiLogger.debug(Logger.SECURITY_FAILURE, message, throwable);
	}

	/**
	 * {@inheritDoc}
	 */
	public void error(String message) {
		esapiLogger.error(Logger.SECURITY_FAILURE, message);
	}

	/**
	 * {@inheritDoc}
	 */
	public void error(String message, Throwable throwable) {
		esapiLogger.error(Logger.SECURITY_FAILURE, message, throwable);
	}

	/**
	 * {@inheritDoc}
	 */
	public void fatal(String message) {
		esapiLogger.fatal(Logger.SECURITY_FAILURE, message);
	}

	/**
	 * {@inheritDoc}
	 */
	public void fatal(String message, Throwable throwable) {
		esapiLogger.fatal(Logger.SECURITY_FAILURE, message, throwable);
	}

	/**
	 * {@inheritDoc}
	 */
	public void info(String message) {
		esapiLogger.info(Logger.SECURITY_FAILURE, message);
	}

	/**
	 * {@inheritDoc}
	 */
	public void info(String message, Throwable throwable) {
		esapiLogger.info(Logger.SECURITY_FAILURE, message, throwable);
	}

	/**
	 * {@inheritDoc}
	 */
	public void warning(String message) {
		esapiLogger.warning(Logger.SECURITY_FAILURE, message);
	}

	/**
	 * {@inheritDoc}
	 */
	public void warning(String message, Throwable throwable) {
		esapiLogger.warning(Logger.SECURITY_FAILURE, message, throwable);
	}
}
